@@ -18,8 +18,9 @@ from __future__ import print_function
 
 import argparse
 
-from neutronclient.i18n import _
+from neutronclient._i18n import _
 from neutronclient.neutron import v2_0 as neutronV20
+from neutronclient.neutron.v2_0 import dns
 
 
 class ListFloatingIP(neutronV20.ListCommand):
@@ -47,7 +48,11 @@ class CreateFloatingIP(neutronV20.CreateCommand):
     def add_known_arguments(self, parser):
         parser.add_argument(
             'floating_network_id', metavar='FLOATING_NETWORK',
-            help=_('Network name or ID to allocate floating IP from.'))
+            help=_('ID or name of the network from which '
+                   'the floating IP is allocated.'))
+        parser.add_argument(
+            '--description',
+            help=_('Description of the floating IP.'))
         parser.add_argument(
             '--port-id',
             help=_('ID of the port to be associated with the floating IP.'))
@@ -64,22 +69,24 @@ class CreateFloatingIP(neutronV20.CreateCommand):
         parser.add_argument(
             '--floating-ip-address',
             help=_('IP address of the floating IP'))
+        parser.add_argument(
+            '--subnet',
+            dest='subnet_id',
+            help=_('Subnet ID on which you want to create the floating IP.'))
+        dns.add_dns_argument_create(parser, self.resource, 'domain')
+        dns.add_dns_argument_create(parser, self.resource, 'name')
 
     def args2body(self, parsed_args):
         _network_id = neutronV20.find_resourceid_by_name_or_id(
             self.get_client(), 'network', parsed_args.floating_network_id)
-        body = {self.resource: {'floating_network_id': _network_id}}
-        if parsed_args.port_id:
-            body[self.resource].update({'port_id': parsed_args.port_id})
-        if parsed_args.tenant_id:
-            body[self.resource].update({'tenant_id': parsed_args.tenant_id})
-        if parsed_args.fixed_ip_address:
-            body[self.resource].update({'fixed_ip_address':
-                                        parsed_args.fixed_ip_address})
-        if parsed_args.floating_ip_address:
-            body[self.resource].update({'floating_ip_address':
-                                        parsed_args.floating_ip_address})
-        return body
+        body = {'floating_network_id': _network_id}
+        neutronV20.update_dict(parsed_args, body,
+                               ['port_id', 'tenant_id',
+                                'fixed_ip_address', 'description',
+                                'floating_ip_address', 'subnet_id'])
+        dns.args2body_dns_create(parsed_args, body, 'domain')
+        dns.args2body_dns_create(parsed_args, body, 'name')
+        return {self.resource: body}
 
 
 class DeleteFloatingIP(neutronV20.DeleteCommand):
@@ -92,7 +99,6 @@ class DeleteFloatingIP(neutronV20.DeleteCommand):
 class AssociateFloatingIP(neutronV20.NeutronCommand):
     """Create a mapping between a floating IP and a fixed IP."""
 
-    api = 'network'
     resource = 'floatingip'
 
     def get_parser(self, prog_name):
@@ -113,15 +119,11 @@ class AssociateFloatingIP(neutronV20.NeutronCommand):
             help=argparse.SUPPRESS)
         return parser
 
-    def run(self, parsed_args):
-        self.log.debug('run(%s)' % parsed_args)
+    def take_action(self, parsed_args):
         neutron_client = self.get_client()
-        neutron_client.format = parsed_args.request_format
         update_dict = {}
-        if parsed_args.port_id:
-            update_dict['port_id'] = parsed_args.port_id
-        if parsed_args.fixed_ip_address:
-            update_dict['fixed_ip_address'] = parsed_args.fixed_ip_address
+        neutronV20.update_dict(parsed_args, update_dict,
+                               ['port_id', 'fixed_ip_address'])
         neutron_client.update_floatingip(parsed_args.floatingip_id,
                                          {'floatingip': update_dict})
         print(_('Associated floating IP %s') % parsed_args.floatingip_id,
@@ -129,10 +131,8 @@ class AssociateFloatingIP(neutronV20.NeutronCommand):
 
 
 class DisassociateFloatingIP(neutronV20.NeutronCommand):
-    """Remove a mapping from a floating IP to a fixed IP.
-    """
+    """Remove a mapping from a floating IP to a fixed IP."""
 
-    api = 'network'
     resource = 'floatingip'
 
     def get_parser(self, prog_name):
@@ -142,10 +142,8 @@ class DisassociateFloatingIP(neutronV20.NeutronCommand):
             help=_('ID of the floating IP to disassociate.'))
         return parser
 
-    def run(self, parsed_args):
-        self.log.debug('run(%s)' % parsed_args)
+    def take_action(self, parsed_args):
         neutron_client = self.get_client()
-        neutron_client.format = parsed_args.request_format
         neutron_client.update_floatingip(parsed_args.floatingip_id,
                                          {'floatingip': {'port_id': None}})
         print(_('Disassociated floating IP %s') % parsed_args.floatingip_id,
