@@ -33,17 +33,19 @@ class TestCreateSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
                'Name',
                'Port Pair',
                'Port Pair Group Parameters',
-               'Project')
+               'Project',
+               'Tap Enabled')
 
-    def get_data(self):
+    def get_data(self, ppg):
         return (
-            self._port_pair_group['description'],
-            self._port_pair_group['id'],
-            self._port_pair_group['group_id'],
-            self._port_pair_group['name'],
-            self._port_pair_group['port_pairs'],
-            self._port_pair_group['port_pair_group_parameters'],
-            self._port_pair_group['project_id']
+            ppg['description'],
+            ppg['id'],
+            ppg['group_id'],
+            ppg['name'],
+            ppg['port_pairs'],
+            ppg['port_pair_group_parameters'],
+            ppg['project_id'],
+            ppg['tap_enabled']
         )
 
     def setUp(self):
@@ -51,9 +53,9 @@ class TestCreateSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
         mock.patch(
             'neutronclient.osc.v2.sfc.sfc_port_pair_group._get_id',
             new=_get_id).start()
-        self.neutronclient.create_port_pair_group = mock.Mock(
+        self.neutronclient.create_sfc_port_pair_group = mock.Mock(
             return_value={'port_pair_group': self._port_pair_group})
-        self.data = self.get_data()
+        self.data = self.get_data(self._port_pair_group)
         # Get the command object to test
         self.cmd = sfc_port_pair_group.CreateSfcPortPairGroup(self.app,
                                                               self.namespace)
@@ -70,10 +72,11 @@ class TestCreateSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = (self.cmd.take_action(parsed_args))
-        self.neutronclient.create_port_pair_group.assert_called_once_with({
+        self.neutronclient.create_sfc_port_pair_group.assert_called_once_with({
             'port_pair_group': {
                 'name': self._port_pair_group['name'],
-                'port_pairs': [self._port_pair_group['port_pairs']]}
+                'port_pairs': [self._port_pair_group['port_pairs']]
+            }
         })
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
@@ -92,7 +95,7 @@ class TestCreateSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = (self.cmd.take_action(parsed_args))
 
-        self.neutronclient.create_port_pair_group.assert_called_once_with({
+        self.neutronclient.create_sfc_port_pair_group.assert_called_once_with({
             'port_pair_group': {
                 'name': self._port_pair_group['name'],
                 'port_pairs': [self._port_pair_group['port_pairs']],
@@ -102,6 +105,46 @@ class TestCreateSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
+    def test_create_tap_enabled_port_pair_group(self):
+        arglist = [
+            "--description", self._port_pair_group['description'],
+            "--port-pair", self._port_pair_group['port_pairs'],
+            self._port_pair_group['name'],
+            "--enable-tap"
+        ]
+        verifylist = [
+            ('port_pairs', [self._port_pair_group['port_pairs']]),
+            ('name', self._port_pair_group['name']),
+            ('description', self._port_pair_group['description']),
+            ('enable_tap', True)
+        ]
+
+        expected_data = self._update_expected_response_data(
+            data={
+                'tap_enabled': True
+            }
+        )
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = (self.cmd.take_action(parsed_args))
+
+        self.neutronclient.create_sfc_port_pair_group.assert_called_once_with({
+            'port_pair_group': {
+                'name': self._port_pair_group['name'],
+                'port_pairs': [self._port_pair_group['port_pairs']],
+                'description': self._port_pair_group['description'],
+                'tap_enabled': True
+            }
+        })
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(expected_data, data)
+
+    def _update_expected_response_data(self, data):
+        # REVISIT(vks1) - This method can be common for other test functions.
+        ppg = fakes.FakeSfcPortPairGroup.create_port_pair_group(data)
+        self.neutronclient.create_sfc_port_pair_group.return_value = {
+            'port_pair_group': ppg}
+        return self.get_data(ppg)
+
 
 class TestDeleteSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
 
@@ -113,14 +156,14 @@ class TestDeleteSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
         mock.patch(
             'neutronclient.osc.v2.sfc.sfc_port_pair_group._get_id',
             new=_get_id).start()
-        self.neutronclient.delete_port_pair_group = mock.Mock(
+        self.neutronclient.delete_sfc_port_pair_group = mock.Mock(
             return_value=None)
         self.cmd = sfc_port_pair_group.DeleteSfcPortPairGroup(self.app,
                                                               self.namespace)
 
     def test_delete_port_pair_group(self):
         client = self.app.client_manager.neutronclient
-        mock_port_pair_group_delete = client.delete_port_pair_group
+        mock_port_pair_group_delete = client.delete_sfc_port_pair_group
         arglist = [
             self._port_pair_group[0]['id'],
         ]
@@ -136,22 +179,25 @@ class TestDeleteSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
 
 class TestListSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
     _ppgs = fakes.FakeSfcPortPairGroup.create_port_pair_groups(count=1)
-    columns = ('ID', 'Name', 'Port Pair', 'Port Pair Group Parameters')
+    columns = ('ID', 'Name', 'Port Pair', 'Port Pair Group Parameters',
+               'Tap Enabled')
     columns_long = ('ID', 'Name', 'Port Pair', 'Port Pair Group Parameters',
-                    'Description', 'Loadbalance ID', 'Project')
+                    'Description', 'Loadbalance ID', 'Project', 'Tap Enabled')
     _port_pair_group = _ppgs[0]
     data = [
         _port_pair_group['id'],
         _port_pair_group['name'],
         _port_pair_group['port_pairs'],
-        _port_pair_group['port_pair_group_parameters']
+        _port_pair_group['port_pair_group_parameters'],
+        _port_pair_group['tap_enabled']
     ]
     data_long = [
         _port_pair_group['id'],
         _port_pair_group['name'],
         _port_pair_group['port_pairs'],
         _port_pair_group['port_pair_group_parameters'],
-        _port_pair_group['description']
+        _port_pair_group['description'],
+        _port_pair_group['tap_enabled']
     ]
     _port_pair_group1 = {'port_pair_groups': _port_pair_group}
     _port_pair_id = _port_pair_group['id']
@@ -162,25 +208,27 @@ class TestListSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
             'neutronclient.osc.v2.sfc.sfc_port_pair_group._get_id',
             new=_get_id).start()
 
-        self.neutronclient.list_port_pair_group = mock.Mock(
+        self.neutronclient.list_sfc_port_pair_groups = mock.Mock(
             return_value={'port_pair_groups': self._ppgs}
         )
         # Get the command object to test
         self.cmd = sfc_port_pair_group.ListSfcPortPairGroup(self.app,
                                                             self.namespace)
 
-    def test_list_port_pair_group(self):
+    def test_list_port_pair_groups(self):
         arglist = []
         verifylist = []
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns = self.cmd.take_action(parsed_args)[0]
-        ppgs = self.neutronclient.list_port_pair_group()['port_pair_groups']
+        ppgs = self.neutronclient \
+            .list_sfc_port_pair_groups()['port_pair_groups']
         ppg = ppgs[0]
         data = [
             ppg['id'],
             ppg['name'],
             ppg['port_pairs'],
-            ppg['port_pair_group_parameters']
+            ppg['port_pair_group_parameters'],
+            ppg['tap_enabled']
         ]
         self.assertEqual(list(self.columns), columns)
         self.assertEqual(self.data, data)
@@ -188,14 +236,16 @@ class TestListSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
     def test_list_with_long_option(self):
         arglist = ['--long']
         verifylist = [('long', True)]
-        ppgs = self.neutronclient.list_port_pair_group()['port_pair_groups']
+        ppgs = self.neutronclient \
+            .list_sfc_port_pair_groups()['port_pair_groups']
         ppg = ppgs[0]
         data = [
             ppg['id'],
             ppg['name'],
             ppg['port_pairs'],
             ppg['port_pair_group_parameters'],
-            ppg['description']
+            ppg['description'],
+            ppg['tap_enabled']
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns_long = self.cmd.take_action(parsed_args)[0]
@@ -217,9 +267,9 @@ class TestSetSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
         mock.patch(
             'neutronclient.osc.v2.sfc.sfc_port_pair_group._get_id',
             new=_get_id).start()
-        self.neutronclient.update_port_pair_group = mock.Mock(
+        self.neutronclient.update_sfc_port_pair_group = mock.Mock(
             return_value=None)
-        self.mocked = self.neutronclient.update_port_pair_group
+        self.mocked = self.neutronclient.update_sfc_port_pair_group
         self.cmd = sfc_port_pair_group.SetSfcPortPairGroup(self.app,
                                                            self.namespace)
 
@@ -265,7 +315,7 @@ class TestSetSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
 
     def test_set_no_port_pair(self):
         client = self.app.client_manager.neutronclient
-        mock_port_pair_group_update = client.update_port_pair_group
+        mock_port_pair_group_update = client.update_sfc_port_pair_group
         arglist = [
             self._port_pair_group_name,
             '--name', 'name_updated',
@@ -299,7 +349,8 @@ class TestShowSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
         _ppg['name'],
         _ppg['port_pairs'],
         _ppg['port_pair_group_parameters'],
-        _ppg['project_id'])
+        _ppg['project_id'],
+        _ppg['tap_enabled'])
     _port_pair_group = {'port_pair_group': _ppg}
     _port_pair_group_id = _ppg['id']
     columns = (
@@ -309,7 +360,9 @@ class TestShowSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
         'Name',
         'Port Pair',
         'Port Pair Group Parameters',
-        'Project')
+        'Project',
+        'Tap Enabled'
+    )
 
     def setUp(self):
         super(TestShowSfcPortPairGroup, self).setUp()
@@ -317,7 +370,7 @@ class TestShowSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
             'neutronclient.osc.v2.sfc.sfc_port_pair_group._get_id',
             new=_get_id).start()
 
-        self.neutronclient.show_port_pair_group = mock.Mock(
+        self.neutronclient.show_sfc_port_pair_group = mock.Mock(
             return_value=self._port_pair_group
         )
         self.cmd = sfc_port_pair_group.ShowSfcPortPairGroup(self.app,
@@ -325,7 +378,7 @@ class TestShowSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
 
     def test_show_port_pair_group(self):
         client = self.app.client_manager.neutronclient
-        mock_port_pair_group_show = client.show_port_pair_group
+        mock_port_pair_group_show = client.show_sfc_port_pair_group
         arglist = [
             self._port_pair_group_id,
         ]
@@ -354,9 +407,9 @@ class TestUnsetSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
         mock.patch(
             'neutronclient.osc.v2.sfc.sfc_port_pair_group._get_id',
             new=_get_id).start()
-        self.neutronclient.update_port_pair_group = mock.Mock(
+        self.neutronclient.update_sfc_port_pair_group = mock.Mock(
             return_value=None)
-        self.mocked = self.neutronclient.update_port_pair_group
+        self.mocked = self.neutronclient.update_sfc_port_pair_group
         self.cmd = sfc_port_pair_group.UnsetSfcPortPairGroup(
             self.app, self.namespace)
 
@@ -406,7 +459,7 @@ class TestUnsetSfcPortPairGroup(fakes.TestNeutronClientOSCV2):
 
     def test_unset_all_port_pair(self):
         client = self.app.client_manager.neutronclient
-        mock_port_pair_group_update = client.update_port_pair_group
+        mock_port_pair_group_update = client.update_sfc_port_pair_group
         arglist = [
             self._port_pair_group_name,
             '--all-port-pair',
